@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -45,7 +45,6 @@ import com.openexchange.file.storage.File.Field;
 import com.openexchange.file.storage.FileStorageAccount;
 import com.openexchange.file.storage.FileStorageExceptionCodes;
 import com.openexchange.file.storage.FileStorageObjectPermission;
-import com.openexchange.file.storage.FileStoragePersistentIDs;
 import com.openexchange.file.storage.FileStorageVersionedFileAccess;
 import com.openexchange.file.storage.FileStorageZippableFolderFileAccess;
 import com.openexchange.file.storage.FileTimedResult;
@@ -80,7 +79,7 @@ import com.openexchange.webdav.client.WebDAVXmlBody;
  * @author <a href="mailto:benjamin.gruedelbach@open-xchange.com">Benjamin Gruedelbach</a>
  * @since v7.10.4
  */
-public class OwnCloudFileAccess extends AbstractWebDAVFileAccess implements FileStorageVersionedFileAccess, ThumbnailAware, FileStorageZippableFolderFileAccess, FileStoragePersistentIDs {
+public class OwnCloudFileAccess extends AbstractWebDAVFileAccess implements FileStorageVersionedFileAccess, ThumbnailAware, FileStorageZippableFolderFileAccess {
 
     private static final Logger LOG = LoggerFactory.getLogger(OwnCloudFileAccess.class);
 
