@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -75,7 +75,7 @@ public class OwnCloudPermissionsUtil {
                         guestPerm.setGroup(false);
                         int perm = OCPermissionToOXPermission(ocShare.getPermission());
                         guestPerm.setPermissions(perm);
-                        guestPerm.setRecipient(new AnonymousRecipient(ocPermissionToOXPermissionBit(ocShare.getPermission()), null, null));
+                        guestPerm.setRecipient(new AnonymousRecipient(ocPermissionToOXPermissionBit(ocShare.getPermission()), null, null, true));
                         result.add(guestPerm);
                         continue;
                 }
